import React, { useState, useEffect, useRef } from 'react';
import { Box } from '@chakra-ui/react';
import { decode } from "blurhash";

function BlurrableImage({ src, thumbSrc, blurHash, isImage, isVideo, onClick }) {
  const [loaded, setLoaded] = useState(false);
  const canvasRef = useRef();

  useEffect(() => {
    if (blurHash) {
      const canvas = canvasRef.current;
      const ctx = canvas.getContext("2d");
      const imageData = ctx.createImageData(200, 200);
      const pixels = decode(blurHash, 200, 200);
      imageData.data.set(pixels);
      ctx.putImageData(imageData, 0, 0);
    }
  }, [blurHash]);

  if (isImage || !isVideo) 
    return (
        <>
          <img src={src} onLoad={e => setLoaded(true)} style={{display:'none'}} alt='Loader' />
          {loaded && 
            <Box w="100%" h="10" bg="blue.500" bg={`url(${src})`} bgPosition='center' bgSize='cover' onClick={onClick} />
          }
          {blurHash &&
            <canvas width={200} height={200} ref={canvasRef} style={{display: !loaded ? 'block' : 'none'}}/>
          }
        </>
    );
  if (isVideo)
    return (
      <Box w="100%" h="10" bg="blue.500" bg={`url(${thumbSrc})`} bgPosition='center' bgSize='cover' onClick={onClick} d='flex' flexDirection='vertical'>
        <div style={{fontSize: 20}}>▶️</div>
      </Box>
    );
  return null;
}

export default BlurrableImage;
