import React from 'react';
import { Box, Button, Heading, Text, Input, Alert, AlertIcon } from "@chakra-ui/react"
import styled from 'styled-components';

import Layout from '../lib/Layout';
import useStore from '../lib/store';

const StyledInput = styled(Input)`
  ::placeholder {
      color: white;
  }
`;

function LoginPage( {  } ) {
  const { firstName, setFirstName, password, setPassword, setLoggedIn, setAuthToken, isLoggingIn, setLoggingIn, loginError, setLoginError } = useStore();

  const login = async () => {
    if (!firstName) return setLoginError('Please enter your first name.');
    setLoggingIn(true);
    setLoginError('');
    const response = await fetch('/api/login', {
      method: 'POST',
      headers: {
        'Content-Type': 'application/json;charset=utf-8'
      },
      body: JSON.stringify({ password }),
    });
    setLoggingIn(false);
    const respJson = await response.json();
    if (respJson.success) {
      setLoggedIn(true);
      setAuthToken(respJson.token);
      
    }
    else {
      setLoginError('Unable to login. Is your password correct?');
    }
  }

  return (
    <Layout>
      <Box pt={30} p={5} bg='teal.400' flex={1} d='flex' flexDirection='column'>
        <Heading size='lg' mt={30} color='white'>👋 Welcome!</Heading>
        <Text mt={5} color='white'>Tom and Will are getting married! 🤵🏽🤵🏼‍♂️ </Text>
        <Text mt={3} color='white'>We'd love for you to be involved by sharing pictures and videos to help us celebrate. If you have nice (or funny!) pictures of us, or would like to send a video message, or even if you just want to see what others have shared, then <b>login below</b>.</Text>
        <Heading size='sm' mt={10} mb={1} color='white'>What is your first name?</Heading>
        <StyledInput autoFocus variant='flushed' color='white' colorScheme='teal' placeholder="Your first name..." size="lg" value={firstName} onChange={e => setFirstName(e.target.value)} />
        <Heading size='sm' mt={5} mb={1} color='white'>Enter the password</Heading>
        <StyledInput variant='flushed' color='white' colorScheme='teal' placeholder="Type your password..." size="lg" type='password' value={password} onChange={e => setPassword(e.target.value)} />
        {loginError &&
          <Alert status="error" mt={5}>
            <AlertIcon /> {loginError}
          </Alert>
        }
        {password?.length > 0 &&
          <Button isLoading={isLoggingIn} size='lg' colorScheme='teal' mt={10} onClick={login}>Login</Button>
        }
      </Box>
    </Layout>
  );
}

export default LoginPage;
