import { S3Client, PutObjectCommand } from "@aws-sdk/client-s3";
import { getSignedUrl } from "@aws-sdk/s3-request-presigner";
import { v4 as uuidv4 } from 'uuid';
import jwt from 'jsonwebtoken';

const s3 = new S3Client({
  endpoint: process.env.S3_ENDPOINT,
  credentials: {
    accessKeyId: process.env.ACCESS_KEY_ID,
    secretAccessKey: process.env.SECRET_ACCESS_KEY,
  },
});

export default async (req, res) => {
  if (req.method === 'GET') {
    const headers = req.headers;

    let audience;
    if (req.headers['authorization']) {
      try {
        const decoded = jwt.verify(req.headers['authorization'], process.env.JWT_SECRET);
        audience = decoded.audience;
      } catch(err) {
        return res.status(403).json({ message: 'Invalid token' });
      }
    }
    if (!audience) return res.status(403).json({ message: 'Authorization required' });

    const params = req.query;
    const extension = params.name.split('.').pop();
    const id = uuidv4();
    const fileName = id + '.' + extension;
    const command = new PutObjectCommand({
      Bucket: process.env.S3_BUCKET,
      Key: fileName,
      ACL: 'public',
      ContentType: params.type,
    });
    const url = await getSignedUrl(s3, command);
    const returnData = { url, fileName };

    // If image return upload URL to optionally upload full-res version
    if (params.type.split('/')[0] === 'image') {
      const fullFileName = id + '_original.' + extension;
      const command = new PutObjectCommand({
        Bucket: process.env.S3_BUCKET,
        Key: fullFileName,
        ACL: 'public',
        ContentType: params.type,
      });
      const fullUrl = await getSignedUrl(s3, command);
      returnData.originalUrl = fullUrl;
      returnData.originalFileName = fullFileName;
    }

    if (params.type.split('/')[0] === 'video') {
      const thumbFileName = id + '_thumb.jpg';
      const command = new PutObjectCommand({
        Bucket: process.env.S3_BUCKET,
        Key: thumbFileName,
        ACL: 'public',
        ContentType: params.type,
      });
      const thumbUrl = await getSignedUrl(s3, command);
      returnData.thumbUrl = thumbUrl;
      returnData.thumbFileName = thumbFileName;
    }

    res.status(200).json(returnData);
  }
}
